@@ -1,6 +1,7 @@
 from .convvt import ConvVTAttention
-from .cross import CrossAttention
+from .cross import CrossAttentionWithClsToken
 from .gated_positional import GatedPositionalSelfAttention
+from .memory_efficient import MemoryEfficientAttention
 from .spatial import SpatialAttention
 from .vanilla import VanillaSelfAttention
 from .window import WindowAttention
