@@ -1,6 +1,5 @@
 import torch
 import torch.nn as nn
-from timm.models.layers import trunc_normal_
 
 from ...encoder.convvt import ConvVTStage
 from ...utils import MODEL_REGISTRY
@@ -86,7 +85,7 @@ class ConvVT(nn.Module):
         for i in range(self.num_stages):
             stage = ConvVTStage(
                 in_channels=in_channels,
-                img_size=img_size // (4 * 2 ** i),
+                img_size=img_size // (4 * 2**i),
                 with_cls_token=False if i < self.num_stages - 1 else True,
                 patch_size=patch_size[i],
                 patch_stride=patch_stride[i],
@@ -113,7 +112,7 @@ class ConvVT(nn.Module):
         self.head = (
             nn.Linear(embedding_dim[-1], n_classes) if n_classes > 0 else nn.Identity()
         )
-        trunc_normal_(self.head.weight, std=0.02)
+        nn.init.trunc_normal_(self.head.weight, std=0.02)
 
     def forward(self, x):
 
