@@ -120,7 +120,7 @@ class DPTDepth(nn.Module):
                 embedding_dim=768,
                 head_dim=64,
                 depth=12,
-                attn_heads=12,
+                num_heads=12,
                 encoder_mlp_dim=768,
                 n_classes=10,
                 in_channels=in_channels,
@@ -137,7 +137,7 @@ class DPTDepth(nn.Module):
                 embedding_dim=1024,
                 head_dim=64,
                 depth=24,
-                attn_heads=16,
+                num_heads=16,
                 encoder_mlp_dim=1024,
                 n_classes=10,
                 in_channels=in_channels,
@@ -154,7 +154,7 @@ class DPTDepth(nn.Module):
                 embedding_dim=192,
                 head_dim=64,
                 depth=12,
-                attn_heads=3,
+                num_heads=3,
                 encoder_mlp_dim=192,
                 n_classes=3,  # doenst matter because decoder part is not used in DPTs forward_vit
                 in_channels=in_channels,
